@@ -4,6 +4,7 @@ from chromadb.api.types import (
     Documents,
     Embeddings,
     IDs,
+    Include,
     Metadatas,
 )
 from chromadb.errors import NoDatapointsException
@@ -91,6 +92,7 @@ class FastAPI(API):
         page=None,
         page_size=None,
         where_document={},
+        include: Include = ["embeddings", "metadatas", "documents"],
     ):
         """Gets embeddings from the database"""
         if page and page_size:
@@ -107,6 +109,7 @@ class FastAPI(API):
                     "limit": limit,
                     "offset": offset,
                     "where_document": where_document,
+                    "include": include,
                 }
             ),
         )
@@ -188,7 +191,15 @@ class FastAPI(API):
         resp.raise_for_status()
         return True
 
-    def _query(self, collection_name, query_embeddings, n_results=10, where={}, where_document={}):
+    def _query(
+        self,
+        collection_name,
+        query_embeddings,
+        n_results=10,
+        where={},
+        where_document={},
+        include: Include = ["embeddings", "metadatas", "documents", "distances"],
+    ):
         """Gets the nearest neighbors of a single embedding"""
 
         resp = requests.post(
@@ -199,6 +210,7 @@ class FastAPI(API):
                     "n_results": n_results,
                     "where": where,
                     "where_document": where_document,
+                    "include": include,
                 }
             ),
         )
