@@ -1,9 +1,9 @@
 import json
 import time
-from typing import Dict, Optional, Sequence, Callable
+from typing import Dict, List, Optional, Sequence, Callable, Type, cast
 from chromadb.api import API
 from chromadb.db import DB
-from chromadb.api.types import GetResult, IDs, QueryResult
+from chromadb.api.types import Embedding, GetResult, IDs, Include, QueryResult
 from chromadb.api.models.Collection import Collection
 
 import re
@@ -116,15 +116,6 @@ class LocalAPI(API):
 
         return True
 
-    def _db_result_to_get_result(self, db_result) -> GetResult:
-        query_result = GetResult(embeddings=[], documents=[], ids=[], metadatas=[])
-        for entry in db_result:
-            query_result["embeddings"].append(entry[2])
-            query_result["documents"].append(entry[3])
-            query_result["ids"].append(entry[4])
-            query_result["metadatas"].append(entry[5])
-        return query_result
-
     def _get(
         self,
         collection_name,
@@ -136,6 +127,7 @@ class LocalAPI(API):
         page=None,
         page_size=None,
         where_document=None,
+        include: Include = ["embeddings", "metadatas", "documents"],
     ):
         if where is None:
             where = {}
@@ -147,18 +139,42 @@ class LocalAPI(API):
             offset = (page - 1) * page_size
             limit = page_size
 
-        return self._db_result_to_get_result(
-            self._db.get(
-                collection_name=collection_name,
-                ids=ids,
-                where=where,
-                sort=sort,
-                limit=limit,
-                offset=offset,
-                where_document=where_document,
-            )
+        include_embeddings = "embeddings" in include
+        include_documents = "documents" in include
+        include_metadatas = "metadatas" in include
+
+        # Remove plural from include since db columns are singular
+        db_columns = [column[:-1] for column in include] + ["id"]
+        column_index = {column_name: index for index, column_name in enumerate(db_columns)}
+
+        db_result = self._db.get(
+            collection_name=collection_name,
+            ids=ids,
+            where=where,
+            sort=sort,
+            limit=limit,
+            offset=offset,
+            where_document=where_document,
+            columns=db_columns,
         )
 
+        get_result = GetResult(
+            ids=[],
+            embeddings=[] if include_embeddings else None,
+            documents=[] if include_documents else None,
+            metadatas=[] if include_metadatas else None,
+        )
+
+        for entry in db_result:
+            if include_embeddings:
+                cast(List, get_result["embeddings"]).append(entry[column_index["embedding"]])
+            if include_documents:
+                cast(List, get_result["documents"]).append(entry[column_index["document"]])
+            if include_metadatas:
+                cast(List, get_result["metadatas"]).append(entry[column_index["metadata"]])
+            get_result["ids"].append(entry[column_index["id"]])
+        return get_result
+
     def _delete(self, collection_name, ids=None, where=None, where_document=None):
         if where is None:
             where = {}
@@ -178,7 +194,15 @@ class LocalAPI(API):
         self._db.reset()
         return True
 
-    def _query(self, collection_name, query_embeddings, n_results=10, where={}, where_document={}):
+    def _query(
+        self,
+        collection_name,
+        query_embeddings,
+        n_results=10,
+        where={},
+        where_document={},
+        include: Include = ["embeddings", "documents", "metadatas", "distances"],
+    ):
         uuids, distances = self._db.get_nearest_neighbors(
             collection_name=collection_name,
             where=where,
@@ -187,25 +211,50 @@ class LocalAPI(API):
             n_results=n_results,
         )
 
-        query_result = QueryResult(embeddings=[], documents=[], ids=[], metadatas=[], distances=[])
+        include_embeddings = "embeddings" in include
+        include_documents = "documents" in include
+        include_metadatas = "metadatas" in include
+        include_distances = "distances" in include
+
+        query_result = QueryResult(
+            ids=[],
+            embeddings=[] if include_embeddings else None,
+            documents=[] if include_documents else None,
+            metadatas=[] if include_metadatas else None,
+            distances=[] if include_distances else None,
+        )
         for i in range(len(uuids)):
             embeddings = []
             documents = []
             ids = []
             metadatas = []
-            db_result = self._db.get_by_ids(uuids[i])
+            # Remove plural from include since db columns are singular
+            db_columns = [column[:-1] for column in include if column != "distances"] + ["id"]
+            column_index = {column_name: index for index, column_name in enumerate(db_columns)}
+            db_result = self._db.get_by_ids(uuids[i], columns=db_columns)
 
             for entry in db_result:
-                embeddings.append(entry[2])
-                documents.append(entry[3])
-                ids.append(entry[4])
-                metadatas.append(json.loads(entry[5]) if entry[5] else None)
+                if include_embeddings:
+                    embeddings.append(entry[column_index["embedding"]])
+                if include_documents:
+                    documents.append(entry[column_index["document"]])
+                if include_metadatas:
+                    metadatas.append(
+                        json.loads(entry[column_index["metadata"]])
+                        if entry[column_index["metadata"]]
+                        else None
+                    )
+                ids.append(entry[column_index["id"]])
 
-            query_result["embeddings"].append(embeddings)
-            query_result["documents"].append(documents)
+            if include_embeddings:
+                cast(List, query_result["embeddings"]).append(embeddings)
+            if include_documents:
+                cast(List, query_result["documents"]).append(documents)
+            if include_metadatas:
+                cast(List, query_result["metadatas"]).append(metadatas)
+            if include_distances:
+                cast(List, query_result["distances"]).append(distances[i].tolist())
             query_result["ids"].append(ids)
-            query_result["metadatas"].append(metadatas)
-            query_result["distances"].append(distances[i].tolist())
 
         return query_result
 
