@@ -1,5 +1,4 @@
-import numbers
-from typing import Literal, Union, Dict, Sequence, TypedDict, Protocol, TypeVar, List
+from typing import Literal, Optional, Union, Dict, Sequence, TypedDict, Protocol, TypeVar, List
 
 ID = str
 IDs = List[ID]
@@ -19,6 +18,7 @@ Parameter = TypeVar("Parameter", Embedding, Document, Metadata, ID)
 T = TypeVar("T")
 OneOrMany = Union[T, List[T]]
 
+Include = List[Literal["documents", "embeddings", "metadatas", "distances"]]
 
 # Grammar for where expressions
 LiteralValue = Union[str, int, float]
@@ -34,17 +34,17 @@ WhereDocument = Dict[WhereDocumentOperator, Union[str, List["WhereDocument"]]]
 
 class GetResult(TypedDict):
     ids: List[ID]
-    embeddings: List[Embedding]
-    documents: List[Document]
-    metadatas: List[Metadata]
+    embeddings: Optional[List[Embedding]]
+    documents: Optional[List[Document]]
+    metadatas: Optional[List[Metadata]]
 
 
 class QueryResult(TypedDict):
     ids: List[IDs]
-    embeddings: List[List[Embedding]]
-    documents: List[List[Document]]
-    metadatas: List[List[Metadata]]
-    distances: List[List[float]]
+    embeddings: Optional[List[List[Embedding]]]
+    documents: Optional[List[List[Document]]]
+    metadatas: Optional[List[List[Metadata]]]
+    distances: Optional[List[List[float]]]
 
 
 class IndexMetadata(TypedDict):
@@ -180,3 +180,17 @@ def validate_where_document(where_document: WhereDocument) -> WhereDocument:
                 f"Where document operand value {operand} must be a string for operator $contains"
             )
     return where_document
+
+
+def validate_include(include: Include, allow_distances: bool) -> Include:
+    """Validates include to ensure it is a list of strings. Since get does not allow distances, allow_distances is used
+    to control if distances is allowed"""
+
+    if not isinstance(include, list):
+        raise ValueError("Include must be a list")
+    for item in include:
+        if not isinstance(item, str):
+            raise ValueError(f"Include item {item} must be a string")
+        if item not in ["embeddings", "documents", "metadatas"] + ["distances"] * allow_distances:
+            raise ValueError(f"Include item {item} value not within allowed values")
+    return include
