@@ -138,6 +138,7 @@ class FastAPI(chromadb.server.Server):
             sort=get.sort,
             limit=get.limit,
             offset=get.offset,
+            include=get.include,
         )
 
     def delete(self, collection_name: str, delete: DeleteEmbedding):
@@ -162,6 +163,7 @@ class FastAPI(chromadb.server.Server):
                 where_document=query.where_document,
                 query_embeddings=query.query_embeddings,
                 n_results=query.n_results,
+                include=query.include,
             )
             return nnresult
         except NoDatapointsException as e:
