@@ -36,6 +36,18 @@ def local_persist_api():
     )
 
 
+# https://docs.pytest.org/en/6.2.x/fixture.html#fixtures-can-be-requested-more-than-once-per-test-return-values-are-cached
+@pytest.fixture
+def local_persist_api_cache_bust():
+    return chromadb.Client(
+        Settings(
+            chroma_api_impl="local",
+            chroma_db_impl="duckdb+parquet",
+            persist_directory=tempfile.gettempdir() + "/test_server",
+        )
+    )
+
+
 @pytest.fixture
 def fastapi_integration_api():
     return chromadb.Client()  # configured by environment variables
@@ -96,6 +108,25 @@ if "CHROMA_INTEGRATION_TEST_ONLY" in os.environ:
     print("Including integration tests only")
     test_apis = [fastapi_integration_api]
 
+
+@pytest.mark.parametrize("api_fixture", [local_persist_api])
+def test_persist_index_loading(api_fixture, request):
+    api = request.getfixturevalue("local_persist_api")
+    api.reset()
+    collection = api.create_collection("test")
+    collection.add(ids="id1", documents="hello")
+
+    api.persist()
+    del api
+
+    api2 = request.getfixturevalue("local_persist_api_cache_bust")
+    collection = api2.get_collection("test")
+
+    nn = collection.query(query_texts="hello", n_results=1)
+    for key in nn.keys():
+        assert len(nn[key]) == 1
+
+
 @pytest.mark.parametrize("api_fixture", [local_persist_api])
 def test_persist(api_fixture, request):
     api = request.getfixturevalue(api_fixture.__name__)
@@ -936,3 +967,78 @@ def test_where_document_logical_operators(api_fixture, request):
 
 
 # endregion
+
+records = {
+    "embeddings": [[0, 0, 0], [1.2, 2.24, 3.2]],
+    "ids": ["id1", "id2"],
+    "metadatas": [{"int_value": 1, "string_value": "one", "float_value": 1.001}, {"int_value": 2}],
+    "documents": ["this document is first", "this document is second"],
+}
+
+
+@pytest.mark.parametrize("api_fixture", test_apis)
+def test_query_include(api_fixture, request):
+    api = request.getfixturevalue(api_fixture.__name__)
+
+    api.reset()
+    collection = api.create_collection("test_query_include")
+    collection.add(**records)
+
+    items = collection.query(
+        query_embeddings=[0, 0, 0], include=["metadatas", "documents", "distances"], n_results=1
+    )
+    assert items["embeddings"] == None
+    assert items["ids"][0][0] == "id1"
+    assert items["metadatas"][0][0]["int_value"] == 1
+
+    items = collection.query(
+        query_embeddings=[0, 0, 0], include=["embeddings", "documents", "distances"], n_results=1
+    )
+    assert items["metadatas"] == None
+    assert items["ids"][0][0] == "id1"
+
+    items = collection.query(
+        query_embeddings=[[0, 0, 0], [1, 2, 1.2]],
+        include=[],
+        n_results=2,
+    )
+    assert items["documents"] == None
+    assert items["metadatas"] == None
+    assert items["embeddings"] == None
+    assert items["distances"] == None
+    assert items["ids"][0][0] == "id1"
+    assert items["ids"][0][1] == "id2"
+
+
+@pytest.mark.parametrize("api_fixture", test_apis)
+def test_get_include(api_fixture, request):
+    api = request.getfixturevalue(api_fixture.__name__)
+
+    api.reset()
+    collection = api.create_collection("test_get_include")
+    collection.add(**records)
+
+    items = collection.get(include=["metadatas", "documents"], where={"int_value": 1})
+    assert items["embeddings"] == None
+    assert items["ids"][0] == "id1"
+    assert items["metadatas"][0]["int_value"] == 1
+    assert items["documents"][0] == "this document is first"
+
+    items = collection.get(include=["embeddings", "documents"])
+    assert items["metadatas"] == None
+    assert items["ids"][0] == "id1"
+    assert items["embeddings"][1][0] == 1.2
+
+    items = collection.get(include=[])
+    assert items["documents"] == None
+    assert items["metadatas"] == None
+    assert items["embeddings"] == None
+    assert items["ids"][0] == "id1"
+
+    with pytest.raises(ValueError) as e:
+        items = collection.get(include=["metadatas", "undefined"])
+    assert "Include" in str(e.value)
+
+    with pytest.raises(ValueError) as e:
+        items = collection.get(include=None)
+    assert "Include" in str(e.value)
